@@ -19,8 +19,10 @@
 /* BSD clones usually do not have */
 #define HAVE_GETUTENT
 
+/* define this for linux 2.2 and above (for O_NOFOLLOW flag) */
+#define __USE_GNU
 
-/* if you are compiling for Cygwin, ucomment this */
+/* if you are compiling for Cygwin, uncomment this */
 /* #define CYGWIN */
 
 /* you probably need not touch variables below */
@@ -35,7 +37,7 @@
 
 #define TTYDIR  "/dev/"
 
-#define VERSION "1.91.2"
+#define VERSION "2.9"
 
 #define LOGFILE ".xtell-log"
 
