@@ -240,8 +240,12 @@ char *tty, *buff;
  */
 short int log_write(const char *toluser, const char *buff)
 {   
+    int filedes;
     FILE *file;
-    if ((file = logFILE(toluser)) != NULL) {
+    if ((filedes = logFILE(toluser)) != -1) {
+        file = fdopen(filedes, "w");
+        if (!file)
+            return 0;
 	fprintf(file, "%s", buff);
 	fclose(file);
     }
